@@ -7,7 +7,7 @@ from inspect import getdoc, getsource
 from numbers import Integral, Number
 from pathlib import Path
 from tempfile import NamedTemporaryFile, TemporaryDirectory
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Sequence, Union, cast
+from typing import IO, TYPE_CHECKING, Any, Callable, Dict, List, Optional, Sequence, Union, cast
 from zipfile import ZipFile
 
 from cognite.client import utils
@@ -104,7 +104,7 @@ class FunctionsAPI(APIClient):
         The function named `handle` is the entrypoint of the created function. Valid arguments to `handle` are `data`, `client`, `secrets` and `function_call_info`:\n
         - If the user calls the function with input data, this is passed through the `data` argument.\n
         - If the user gives an `api_key` when creating the function, a pre instantiated CogniteClient is passed through the `client` argument.\n
-        - If the user gives one ore more secrets when creating the function, these are passed through the `secrets` argument. The API key can be access through `secrets["apikey"]`.\n
+        - If the user gives one or more secrets when creating the function, these are passed through the `secrets` argument. The API key can be access through `secrets["apikey"]`.\n
         - Data about the function call can be accessed via the argument `function_call_info`, which is a dictionary with keys `function_id` and, if the call is scheduled, `schedule_id` and `scheduled_time`.\n
 
         Args:
@@ -443,8 +443,8 @@ class FunctionsAPI(APIClient):
                             reqs = _extract_requirements_from_file(path)
                             # Validate and format requirements
                             parsed_reqs = _validate_and_parse_requirements(reqs)
-                            with NamedTemporaryFile() as nth:
-                                _write_requirements_to_file(nth.name, parsed_reqs)
+                            with NamedTemporaryFile(mode="w+") as nth:
+                                _write_requirements_to_named_temp_file(nth, parsed_reqs)
                                 # NOTE: the actual file is not written.
                                 # A temporary formatted file is used instead
                                 zf.write(nth.name, arcname=REQUIREMENTS_FILE_NAME)
@@ -477,8 +477,8 @@ class FunctionsAPI(APIClient):
                 f.write(source)
 
             # Read and validate requirements
-            with NamedTemporaryFile() as named_temp_file:
-                requirements_written = _write_fn_docstring_requirements_to_file(function_handle, named_temp_file.name)
+            with NamedTemporaryFile(mode="w+") as named_temp_file:
+                requirements_written = _write_fn_docstring_requirements_to_file(function_handle, named_temp_file)
 
                 zip_path = os.path.join(tmpdir, "function.zip")
                 with ZipFile(zip_path, "w") as zf:
@@ -729,12 +729,11 @@ def _validate_and_parse_requirements(requirements: List[str]) -> List[str]:
     return parsed_reqs
 
 
-def _write_requirements_to_file(file_path: str, requirements: List[str]) -> None:
-    with open(file_path, "w+") as f:
-        f.write("\n".join(requirements))
+def _write_requirements_to_named_temp_file(file: IO, requirements: List[str]) -> None:
+    file.write("\n".join(requirements))
 
 
-def _write_fn_docstring_requirements_to_file(fn: Callable, file_path: str) -> bool:
+def _write_fn_docstring_requirements_to_file(fn: Callable, file: IO) -> bool:
     """Read requirements from a function docstring, validate them, and write contents to the provided file path
 
     Args:
@@ -750,7 +749,7 @@ def _write_fn_docstring_requirements_to_file(fn: Callable, file_path: str) -> bo
         reqs = _extract_requirements_from_doc_string(docstr)
         if reqs:
             parsed_reqs = _validate_and_parse_requirements(reqs)
-            _write_requirements_to_file(file_path, parsed_reqs)
+            _write_requirements_to_named_temp_file(file, parsed_reqs)
             return True
 
     return False
